@@ -8,6 +8,18 @@ def flattened_list_of_lists(list_of_lists: List[List], unique: bool = False) ->
 
     return flat
 
+def all_indxs_in_lst(lst: List, value) -> List[int]:
+    idxs = []
+    idx = -1
+    while True:
+        try:
+            idx = lst.index(value, idx + 1)
+            idxs.append(idx)
+        except ValueError as e:
+            break
+    return idxs
+
+
 if __name__ == "__main__":
     import random as rnd
     l_o_l = [[x for x in range(rnd.randint(5, 10))] for y in range(rnd.randint(5, 10))]
